#!/bin/ksh
#-----------------------------------------------------------------------
#! Installation script for SLIME
##
#-----------------------------------------------------------------------
#  Copyright (C) 1997
#  Associated Universities, Inc. Washington DC, USA.
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of
#  the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public
#  License along with this program; if not, write to the Free
#  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
#  MA 02139, USA.
#
#  Correspondence concerning AIPS should be addressed as follows:
#         Internet email: aipsmail@nrao.edu.
#         Postal address: AIPS Project Office
#                         National Radio Astronomy Observatory
#                         520 Edgemont Road
#                         Charlottesville, VA 22903-2475 USA
#-----------------------------------------------------------------------
#   All rights reserved.
#-----------------------------------------------------------------------

#-----------------------------------------------------------------------
# environmentOK is true if AIPS_ROOT, TST, LOAD and HLPFIL are all
# defined.
#-----------------------------------------------------------------------
environmentOK()
{
  typeset -l result
  result=0	# 0 indicates truth

  # Each required variable that is undefined increments result.  A
  # non-zero value of result is interpreted as false.
  if [ -z $AIPS_ROOT ]
  then
      result=$(( result + 1 ))
  fi
  if [ -z $TST ] 
  then
    result=$(( result + 1 ))
  fi
  if [ -z $HLPFIL ]
  then
      result=$(( result + 1 ))
  fi
  if [ -z $LOAD ]
  then 
    result=$(( result + 1 ))
  fi

  return $result
}

#-----------------------------------------------------------------------
# dirsOK is true if, for each of $AIPS_ROOT/app-defaults and 
# $AIPS_ROOT/bitmaps, either:
# - the file does not exist and this process has permission to create
#   them or
# - the file exists, is a directory and this process has permission to
#   create files in it
# and the current process can create files in $LOAD and $HLPFIL
#
# Error messages are produced as a side effect of evaluating this
# function.
#
# Precondition: $AIPS_ROOT is defined
#-----------------------------------------------------------------------
dirsOK()
{
  typeset -l result

  result=0

  for d in $AIPS_ROOT/app-defaults $AIPS_ROOT/bitmaps
  do
    if [ -r $d -o -w $d -o -x $d ]
    then
      if [ ! -d $d ]
      then
	echo "  $d is not a directory."
	result=1
      elif [ ! -w $d ]
      then
	echo "  I can not create files in $d."
	echo "  Make sure that you are running as the AIPS manager."
	result=1
      fi
    else
      if [ ! -d $AIPS_ROOT ]
      then
	echo "  $AIPS_ROOT is not a directory."
	result=1
      elif [ ! -w $AIPS_ROOT ]
      then
	echo "  I can not create files in $AIPS_ROOT"
      	echo "  Make sure that you are running as the AIPS manager."
	result=1
      fi
    fi
  done

  for d in $LOAD $HLPFIL
  do
    if [ ! -d $d ]
    then
      echo "  $d is not a directory."
      result=1
    elif [ ! -w $d ]
    then
      echo "  I can not create files in $d"
      echo "  Make sure that you are running as the AIPS manager."
      result=1
    fi
  done

  return $result
}

#-----------------------------------------------------------------------
# versionOK is true if the TST version of AIPS is 15APR98 or later or if
# the user has responded to a prompt asking if SLIME should be installed
# in his current version of AIPS.
#
# Precondition: $TST is defined
#-----------------------------------------------------------------------
versionOK()
{
  typeset -l result
  typeset -l reply
  typeset -l badReply

  case $TST in
    */15APR98) result=0
               ;;
    */15OCT98) result=0
               ;;
    */15APR99) result=0
               ;;
    */15OCT99) result=0
               ;;
    *)         badReply=0 # true
               echo
               echo "  This version of SLIME is intended for 15APR98 or later."
	       echo "  You have ${TST##*/}: do you want to install SLIME anyway?"
	       result=1
               while [ $badReply == 0 ]
	       do
		 if read -r reply
		 then
		   case $reply in
		     y|yes)	result=0
                                badReply=1
			        ;;
		     n|no)      result=1
                                badReply=1
				;;
		     *)         echo "  Please answer 'yes' or 'no'."
			        badReply=0
			        ;;
		   esac
		 fi
	       done
  esac

  echo
  return $result
}

#-----------------------------------------------------------------------
# Create $AIPS_ROOT/app-defaults and $AIPS_ROOT/bitmaps if necessary
#
# Preconditions: $AIPS_ROOT is defined and is a writable directory
#                and each of $AIPS_ROOT/app-defaults and 
#                $AIPS_ROOT/bitmaps is either a directory or does not
#                exist
#-----------------------------------------------------------------------
createDirs()
{
  umask 002

  for d in $AIPS_ROOT/app-defaults $AIPS_ROOT/bitmaps
  do
    if [ ! -d $d ]
    then
      echo "  Creating $d"
      mkdir $d
    fi
  done
}

#-----------------------------------------------------------------------
# Install SLIME
#
# Preconditions: $AIPS_ROOT, $LOAD and $HLPFIL are defined and
#                $AIPS_ROOT/app-defaults, $AIPS_ROOT/bitmaps, $LOAD
#                and $HLPFIL are writable directories
#-----------------------------------------------------------------------
installFiles()
{
  umask 002

  echo "  Installing files."

  rm -rf $LOAD/SLIME.EXE
  cp SLIME.EXE $LOAD
  rm -rf $HLPFIL/SLIME.HLP
  cp SLIME.HLP $HLPFIL
  rm -rf $AIPS_ROOT/app-defaults/Slime
  cp Slime.ad $AIPS_ROOT/app-defaults/Slime
  rm -rf $AIPS_ROOT/bitmaps/scan?
  cp scan? $AIPS_ROOT/bitmaps
}

#-----------------------------------------------------------------------
# Check that the preconditions for installing SLIME have been met and,
# if so, install SLIME.
#-----------------------------------------------------------------------

echo "Checking AIPS environment..."
if environmentOK
then
  echo "AIPS environment OK."
else
  echo "The AIPS environment variables are not defined.  Dot the LOGIN.SH"
  echo "file and type \$CDTST before running this script again."
  exit 1
fi

echo "Checking directories and permissions..."
if dirsOK
then
  echo "Directories and permissions OK."
else
  echo "There are problems with the output directories and/or permissions."
  exit 1
fi

echo "Checking your version of AIPS..."
if versionOK
then
  echo "AIPS version OK."
else
  echo "SLIME will not be installed."
  exit 1
fi

echo "Installing SLIME..."
createDirs
installFiles
echo "SLIME has been installed successfully."

  

